<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Arkivhåndterer&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>En enkel og skrivebordsmiljøuavhengig Qt arkivhåndterer</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>Opphavsmenn</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Programmering:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver har kode fra disse programmene:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>LXQt Archiver

Opphavsrett © 2020 LXQt-laget

Dette programmet er fri programvare. Du kan redistribuere det 
og/eller endre det under vilkårene i GNU General Public License
som publisert av the Free Software Foundation, enten versjon 2
av lisensen eller (etter eget ønske) enhver senere versjon.

Dette programmet blir distribuert i håpet at det vil være nyttig,
men UTEN NOEN GARANTIER. Selv uten de usagte garantiene 
om salgbarhet eller egnethet for et bestemt formål. Se GNU 
General Public License for flere detaljer.

Du burde ha mottatt en kopi av GNU General Public License ved siden 
av dette programmet. Hvis ikke, skriv til the Free Software Foundation 
Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Arkivtype støttes ikke.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 filer (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Alle støttede formater</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Klarte ikke å utføre kommandoen.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Kommandoen blir ikke funnet.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>Kommandoen avsluttet unormalt.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Passord kreves.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Manglende volum.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Dårlig tegnsett.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Filformatet støttes ikke.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Ukjente feil har oppstått.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Del inn i volumer på</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Krypter fillisten også</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="12"/>
        <source>Create Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createfiledialog.cpp" line="14"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Pakk ut</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>P&amp;akk ut alle filer</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Pa&amp;kk ut valgte filer</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Handlinger</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Opprett mapper på nytt</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>Overskriv eksisterende filer</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>Ikke pakk ut gamle filer</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="11"/>
        <source>Extract</source>
        <translation type="unfinished">Pakk ut</translation>
    </message>
    <message>
        <location filename="../extractfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>File Archiver</source>
        <translation>Arkivhåndterer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>Filrer filer...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>&amp;Icon Size</source>
        <translation>&amp;Ikonstørrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Main Toolbar</source>
        <translation>Hovedverktøylinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>&amp;Open</source>
        <translation>&amp;Åpne</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="213"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Save &amp;As</source>
        <translation>Lagre &amp;som</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Extract</source>
        <translation>&amp;Pakk ut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;Test</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="249"/>
        <source>&amp;Properties</source>
        <translation>&amp;Egenskaper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="252"/>
        <source>Alt+Return</source>
        <translation>Alt+Retur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>Cu&amp;t</source>
        <translation>Kli&amp;pp ut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>&amp;Paste</source>
        <translation>&amp;Lim inn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>&amp;Rename</source>
        <translation>&amp;Gi nytt navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="317"/>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>&amp;Select All</source>
        <translation>&amp;Velg alle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>&amp;Find</source>
        <translation>&amp;Finn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <location filename="../mainwindow.ui" line="462"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>&amp;Add Files</source>
        <translation>&amp;Legg til filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Add F&amp;older</source>
        <translation>Legg &amp;til mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>Pass&amp;word</source>
        <translation>Pass&amp;ord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="373"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Verktøylinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Statuslinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;Mappetre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="406"/>
        <source>S&amp;how as Folder</source>
        <translation>V&amp;is som mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Show &amp;All Files</source>
        <translation>Vis &amp;alle filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>St&amp;op</source>
        <translation>St&amp;opp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Esc</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>&amp;Reload</source>
        <translation>&amp;Last inn på nytt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Filename &amp;Encoding</source>
        <translation>Filnavnets t&amp;egnsett</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>&amp;View Selected Items</source>
        <translation>&amp;Vis valgte elementer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Filter</source>
        <translation>&amp;Filtrer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>&amp;Expand</source>
        <translation>&amp;Utvid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>&amp;Collapse</source>
        <translation>&amp;Fold sammen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>16 px</source>
        <translation>16 piksler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>24 px</source>
        <translation>24 piksler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>32 px</source>
        <translation>32 piksler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>48 px</source>
        <translation>48 piksler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <location filename="../mainwindow.cpp" line="397"/>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Add only if &amp;newer</source>
        <translation>Legg til bare hvis &amp;nyere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Confirm</source>
        <translation>Bekreft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Er du sikker på at du vil slette valgte filer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="754"/>
        <source>Version: %1</source>
        <translation>Versjon: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>%p %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Success</source>
        <translation>Suksess</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>No errors have been found.</source>
        <translation>Ingen feil har blitt funnet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="923"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Add Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Add Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1008"/>
        <source>N/A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>Uncompressed Size:</source>
        <translation>Utpakket størrelse:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1014"/>
        <source>Compression Ratio:</source>
        <translation>Kompresjonsfaktor:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1033"/>
        <source>Link to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1072"/>
        <source>File name</source>
        <translation>Filnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1073"/>
        <source>File Type</source>
        <translation>Filtype</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1074"/>
        <source>File Size</source>
        <translation>Filstørrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Modified</source>
        <translation>Sist endret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1076"/>
        <source>Encrypted</source>
        <translation>Kryptert</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1102"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n fil</numerusform>
            <numerusform>%n filer</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Krypter fillisten</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Vis passord</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Merk:&lt;/b&gt; passordet blir brukt til å kryptere filer du legger til det nåværende arkivet og til å dekryptere filer du pakker ut fra det nåværende arkivet. Når arkivet blir lukket kommer passordet til å slettes.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Framdrift</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar komprimert med 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar komprimert med bzip2 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar komprimert med bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Rar-pakket tegneserie (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Zip-pakket tegneserie (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar komprimert med gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Selvutpakkende zip (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar komprimert med lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar komprimert med lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar komprimert med lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar komprimert med lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>Windows diskbildeformat (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Tar ukomprimert (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar komprimert med compress (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar komprimert med xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar komprimert med zstd (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>Legger til fil: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>Pakker ut fil: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>Fjerner fil: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>Fjerner filer fra arkiv</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>Komprimerer arkiv på nytt</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>Pakker ut arkiv</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Fant ikke fil.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Arkivtypen støttes ikke.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Fant ikke arkivtypen</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Du har ikke riktige tillatelser.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Denne typen arkiv kan ikke endres</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Du kan ikke legge arkiv til seg selv.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Fant ikke volumet: %s</translation>
    </message>
</context>
</TS>
